pub struct FunctionDefinition {
pub name: String,
pub description: Option<String>,
pub parameters: Option<HashMap<String, Value>>,
}Fields
name: StringThe name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
description: Option<String>A description of what the function does, used by the model to choose when and how to call the function.
parameters: Option<HashMap<String, Value>>The parameters the function accepts, described as a JSON Schema object.
Implementations
Sourceimpl FunctionDefinition
impl FunctionDefinition
pub fn new(name: String) -> FunctionDefinition